Basic workflow
==============

.. tutorial_0_basic_workflow.py
.. ++++++++++++++++++++++++++++
.. .. literalinclude:: ../tutorials/ml-workflows/tutorial_0_basic_workflow.py
   :language: python

.. literalinclude:: ../tutorials/ml-workflows/tutorial_0_basic_workflow.py
   :language: python

.. .. automodule:: tutorial_0_basic_workflow
..    :members:
..    :undoc-members:
..    :show-inheritance:
